==> milvus-sdk-java-2.0.1-sources.jar: io/milvus/param/partition/GetPartitionStatisticsParam.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milvus.param.partition;

import io.milvus.exception.ParamException;
import io.milvus.param.ParamUtils;

import lombok.Getter;
import lombok.NonNull;

/**
 * Parameters for <code>getPartitionStatistics</code> interface.
 */
@Getter
public class GetPartitionStatisticsParam {
    private final String collectionName;
    private final String partitionName;
    private final boolean flushCollection;

    private GetPartitionStatisticsParam(@NonNull Builder builder) {
        this.collectionName = builder.collectionName;
        this.partitionName = builder.partitionName;
        this.flushCollection = builder.flushCollection;
    }

    public static Builder newBuilder() {
        return new Builder();
    }

    /**
     * Builder for <code>GetPartitionStatisticsParam</code> class.
     */
    public static final class Builder {
        private String collectionName;
        private String partitionName;

        // if flushCollection is true, getCollectionStatistics() firstly call flush() and wait flush() finish
        // Note: use default interval and timeout to wait flush()
        private Boolean flushCollection = Boolean.TRUE;

        private Builder() {
        }

        /**
         * Sets the collection name. Collection name cannot be empty or null.
         *
         * @param collectionName collection name
         * @return <code>Builder</code>
         */
        public Builder withCollectionName(@NonNull String collectionName) {
            this.collectionName = collectionName;
            return this;
        }

        /**
         * Sets the partition name. Partition name cannot be empty or null.
         *
         * @param partitionName partition name
         * @return <code>Builder</code>
         */
        public Builder withPartitionName(@NonNull String partitionName) {
            this.partitionName = partitionName;
            return this;
        }

        /**
         * Requires a flush action before retrieving partition statistics.
         *
         * @param flush <code>Boolean.TRUE</code> require a flush action
         * @return <code>Builder</code>
         */
        public Builder withFlush(@NonNull Boolean flush) {
            this.flushCollection = flush;
            return this;
        }

        /**
         * Verifies parameters and creates a new <code>GetPartitionStatisticsParam</code> instance.
         *
         * @return <code>GetPartitionStatisticsParam</code>
         */
        public GetPartitionStatisticsParam build() throws ParamException {
            ParamUtils.CheckNullEmptyString(collectionName, "Collection name");
            ParamUtils.CheckNullEmptyString(partitionName, "Partition name");

            return new GetPartitionStatisticsParam(this);
        }
    }

    /**
     * Constructs a <code>String</code> by <code>GetPartitionStatisticsParam</code> instance.
     *
     * @return <code>String</code>
     */
    @Override
    public String toString() {
        return "GetPartitionStatisticsParam{" +
                "collectionName='" + collectionName + '\'' +
                ", partitionName='" + partitionName + '\'' +
                ", flush=" + flushCollection +
                '}';
    }
}

==> milvus-sdk-java-2.2.2-sources.jar: io/milvus/param/partition/GetPartitionStatisticsParam.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milvus.param.partition;

import io.milvus.exception.ParamException;
import io.milvus.param.ParamUtils;

import lombok.Getter;
import lombok.NonNull;

/**
 * Parameters for <code>getPartitionStatistics</code> interface.
 */
@Getter
public class GetPartitionStatisticsParam {
    private final String collectionName;
    private final String partitionName;
    private final boolean flushCollection;

    private GetPartitionStatisticsParam(@NonNull Builder builder) {
        this.collectionName = builder.collectionName;
        this.partitionName = builder.partitionName;
        this.flushCollection = builder.flushCollection;
    }

    public static Builder newBuilder() {
        return new Builder();
    }

    /**
     * Builder for {@link GetPartitionStatisticsParam} class.
     */
    public static final class Builder {
        private String collectionName;
        private String partitionName;

        // if flushCollection is true, getCollectionStatistics() firstly call flush() and wait flush() finish
        // Note: use default interval and timeout to wait flush()
        private Boolean flushCollection = Boolean.FALSE;

        private Builder() {
        }

        /**
         * Sets the collection name. Collection name cannot be empty or null.
         *
         * @param collectionName collection name
         * @return <code>Builder</code>
         */
        public Builder withCollectionName(@NonNull String collectionName) {
            this.collectionName = collectionName;
            return this;
        }

        /**
         * Sets the partition name. Partition name cannot be empty or null.
         *
         * @param partitionName partition name
         * @return <code>Builder</code>
         */
        public Builder withPartitionName(@NonNull String partitionName) {
            this.partitionName = partitionName;
            return this;
        }

        /**
         * Requires a flush action before retrieving partition statistics.
         *
         * @param flush <code>Boolean.TRUE</code> require a flush action
         * @return <code>Builder</code>
         */
        public Builder withFlush(@NonNull Boolean flush) {
            this.flushCollection = flush;
            return this;
        }

        /**
         * Verifies parameters and creates a new {@link GetPartitionStatisticsParam} instance.
         *
         * @return {@link GetPartitionStatisticsParam}
         */
        public GetPartitionStatisticsParam build() throws ParamException {
            ParamUtils.CheckNullEmptyString(collectionName, "Collection name");
            ParamUtils.CheckNullEmptyString(partitionName, "Partition name");

            return new GetPartitionStatisticsParam(this);
        }
    }

    /**
     * Constructs a <code>String</code> by {@link GetPartitionStatisticsParam} instance.
     *
     * @return <code>String</code>
     */
    @Override
    public String toString() {
        return "GetPartitionStatisticsParam{" +
                "collectionName='" + collectionName + '\'' +
                ", partitionName='" + partitionName + '\'' +
                ", flush=" + flushCollection +
                '}';
    }
}
